# DISCLAIMER

Before running the test generation script or examples, please read the following disclaimer carefully:

The data used by these tests is licensed under the CC BY-NC-SA 3.0 license, as detailed here:
https://github.com/radoss-org/radoss-creative-commons

By running tests or examples with this data, you agree to abide by the terms of the CC BY-NC-SA 3.0 license:
- You may share and adapt the data, but you must give appropriate credit, provide a link to the license, and indicate if changes were made.
- You may not use the data for commercial purposes.
- If you remix, transform, or build upon the data, you must distribute your contributions under the same license.

The examples can be identified by their use of the `download_case` function, which downloads data from the radoss-creative-commons repository.

The tests can be identified from the `poe testgen` command, which generates required test data from the radoss-creative-commons repository.

If you do not agree to these terms, do not proceed with running these tests.

Please type "yes" to confirm that you have read and agree to the terms of the CC BY-NC-SA 3.0 license.

